@@ -324,9 +324,11 @@ def combine_results(allout):
                 f.write("\t".join(line))
                 f.write("\n")
 
-def in_trigram_context_entropy(w_one,w_two):
-    w_one_contexts = {x.get_context(): x.count for y in w_one for x in y.word.all()}
-    w_two_contexts = {x.get_context(): x.count for y in w_two for x in y.word.all()}
+def in_trigram_context_entropy(wordOne,wordTwo):
+    w_one = [for y in wordOne for x in y.word.all()]
+    w_one = [for y in wordTwo for x in y.word.all()]
+    w_one_contexts = {x.get_context(): x.count for x in w_one}
+    w_two_contexts = {x.get_context(): x.count for x in w_two}
     w_one_contexts.update({x:0 for x in w_two_contexts if x not in w_one_contexts})
     w_two_contexts.update({x:0 for x in w_one_contexts if x not in w_two_contexts})
     #print(w_one_contexts)
